==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/grail/dialogs_nl.lua <==

dialogId("gr-m-gral", "font_small", "That thing over there must be Holy Grail!")
dialogStr("Dat ding daar is vast de Heilige Graal!")


dialogId("gr-v-jiste", "font_big", "How can you be so sure?")
dialogStr("Hoe weet je dat zo zeker?")


dialogId("gr-m-zare0", "font_small", "Can`t you see that halo?")
dialogStr("Zie je die aureool niet?")


dialogId("gr-m-zare1", "font_small", "Can`t you see how it glows among the others?")
dialogStr("Zie je niet hoe hij schijnt tussen die anderen?")


dialogId("gr-m-zare2", "font_small", "Can`t you see how conspicuously is it placed in the center of the cave?")
dialogStr("Zie je niet hoe hij op lekker opvallend in het midden van de grot staat?")


dialogId("gr-v-nic0", "font_big", "The halo means nothing. The Holy Grail could look quite plain.")
dialogStr("Een aureool zegt helemaal niks. De Heilige Graal zou er ook heel eenvoudig uit kunnen zien.")


dialogId("gr-v-nic1", "font_big", "All that glitters is not gold. No one ever said that Holy Grail must glow.")
dialogStr("Niet alles wat glimt is goud. Niemand heeft ooit gezegd dat de Heilge Graal moet schijnen.")


dialogId("gr-v-nic2", "font_big", "Hmm... Placing a plain Grail in a conspicuous place will not turn it into a Holy one.")
dialogStr("Hmm... Een eevoudige graal op een opvallende plek neer zetten maakt hem nog niet Heilig.")


dialogId("gr-v-tuseni", "font_big", "I feel it will not be as it seems.")
dialogStr("Ik heb het gevoel dat het niet allemaal zo is als het lijkt.")


dialogId("gr-m-tuseni", "font_small", "You and your feelings.")
dialogStr("Jij en je gevoel ook altijd.")


dialogId("gr-m-svaty0", "font_small", "Let`s go, we shall take that central glowing Grail with us.")
dialogStr("Nou ja, we nemen gewoon die schijnende Graal daar in het midden mee.")


dialogId("gr-v-vsechny0", "font_big", "I`d rather take all of them.")
dialogStr("Ik zou ze liever allemaal meenemen.")


dialogId("gr-m-vsechny0", "font_small", "Hmm... It seems you were right. We`ll take them all.")
dialogStr("Hmm... ja, je hebt gelijk. We nemen ze allemaal mee.")


dialogId("gr-m-svaty1", "font_small", "Our goal in this level is to push out the Holy Grail.")
dialogStr("In dit veld is het ons doel, de Heilige Graal hieruit te krijgen.")


dialogId("gr-v-vsechny1", "font_big", "No, to push out all the Grails.")
dialogStr("Nee, alle Gralen.")


dialogId("gr-m-jensvaty", "font_small", "The Holy one is enough.")
dialogStr("Nee, alleen de Heilige is goed genoeg.")


dialogId("gr-m-vsechny1", "font_small", "Our goal is to push all the Grails out of this room.")
dialogStr("Ons doel is om alle Gralen uit deze kamer te duwen.")


dialogId("gr-v-skoro0", "font_big", "Almost all of them are gone, now!")
dialogStr("Ze zijn al bijna allemaal weg!")


dialogId("gr-v-skoro1", "font_big", "One more Grail and we are done!")
dialogStr("Nog maar één Graal en dan zijn we klaar!")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/grail/dialogs_nl.lua <==

dialogId("gr-m-gral", "font_small", "That thing over there must be Holy Grail!")
dialogStr("Dat ding daar is vast de Heilige Graal!")


dialogId("gr-v-jiste", "font_big", "How can you be so sure?")
dialogStr("Hoe weet je dat zo zeker?")


dialogId("gr-m-zare0", "font_small", "Can’t you see that halo?")
dialogStr("Zie je die aureool niet?")


dialogId("gr-m-zare1", "font_small", "Can’t you see how it glows among the others?")
dialogStr("Zie je niet hoe hij straalt tussen die anderen?")


dialogId("gr-m-zare2", "font_small", "Can’t you see how conspicuously is it placed in the center of the cave?")
dialogStr("Zie je niet hoe hij lekker opvallend in het midden van de grot staat?")


dialogId("gr-v-nic0", "font_big", "The halo means nothing. The Holy Grail could look quite plain.")
dialogStr("Een aureool zegt helemaal niks. De Heilige Graal zou er ook heel eenvoudig uit kunnen zien.")


dialogId("gr-v-nic1", "font_big", "All that glitters is not gold. No one ever said that Holy Grail must glow.")
dialogStr("Niet alles wat glimt is goud. Niemand heeft ooit gezegd dat de Heilge Graal moet stralen.")


dialogId("gr-v-nic2", "font_big", "Hmm... Placing a plain Grail in a conspicuous place will not turn it into a Holy one.")
dialogStr("Hmm... Een eevoudige graal op een opvallende plek neer zetten maakt hem nog niet Heilig.")


dialogId("gr-v-tuseni", "font_big", "I feel it will not be as it seems.")
dialogStr("Ik heb het gevoel dat het niet allemaal zo is als het lijkt.")


dialogId("gr-m-tuseni", "font_small", "You and your feelings.")
dialogStr("Jij en je gevoel ook altijd.")


dialogId("gr-m-svaty0", "font_small", "Let’s go, we shall take that central glowing Grail with us.")
dialogStr("Nou ja, we nemen gewoon die stralende Graal daar in het midden mee.")


dialogId("gr-v-vsechny0", "font_big", "I’d rather take all of them.")
dialogStr("Ik zou ze liever allemaal meenemen.")


dialogId("gr-m-vsechny0", "font_small", "Hmm... It seems you were right. We’ll take them all.")
dialogStr("Hmm... ja, je hebt gelijk. We nemen ze allemaal mee.")


dialogId("gr-m-svaty1", "font_small", "Our goal in this level is to push out the Holy Grail.")
dialogStr("In dit veld is het ons doel, de Heilige Graal hieruit te krijgen.")


dialogId("gr-v-vsechny1", "font_big", "No, to push out all the Grails.")
dialogStr("Nee, alle Gralen.")


dialogId("gr-m-jensvaty", "font_small", "The Holy one is enough.")
dialogStr("Nee, alleen de Heilige is goed genoeg.")


dialogId("gr-m-vsechny1", "font_small", "Our goal is to push all the Grails out of this room.")
dialogStr("Ons doel is om alle Gralen uit deze kamer te duwen.")


dialogId("gr-v-skoro0", "font_big", "Almost all of them are gone, now!")
dialogStr("Ze zijn al bijna allemaal weg!")


dialogId("gr-v-skoro1", "font_big", "One more Grail and we are done!")
dialogStr("Nog maar één Graal en dan zijn we klaar!")
